@@ -4,16 +4,14 @@ Main interface for appconfig service.
 Usage::
 
     ```python
-    import boto3
+    from boto3.session import Session
     from mypy_boto3_appconfig import (
         AppConfigClient,
         Client,
     )
 
-    session = boto3.Session()
-
-    client: AppConfigClient = boto3.client("appconfig")
-    session_client: AppConfigClient = session.client("appconfig")
+    session = Session()
+    client: AppConfigClient = session.client("appconfig")
     ```
 """
 from .client import AppConfigClient
