@@ -1,7 +1,7 @@
 """
 Type annotations for appconfig service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/type_defs.html)
+[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_appconfig/type_defs/)
 
 Usage::
 
@@ -13,7 +13,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import IO, Dict, List, Mapping, Sequence, Union
+from typing import IO, Any, Dict, List, Mapping, Sequence, Union
 
 from botocore.response import StreamingBody
 
@@ -130,6 +130,7 @@ ConfigurationProfileSummaryTypeDef = TypedDict(
         "Name": str,
         "LocationUri": str,
         "ValidatorTypes": List[ValidatorTypeType],
+        "Type": str,
     },
     total=False,
 )
@@ -144,6 +145,7 @@ ConfigurationProfileTypeDef = TypedDict(
         "LocationUri": str,
         "RetrievalRoleArn": str,
         "Validators": List["ValidatorTypeDef"],
+        "Type": str,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
@@ -204,6 +206,7 @@ _OptionalCreateConfigurationProfileRequestRequestTypeDef = TypedDict(
         "RetrievalRoleArn": str,
         "Validators": Sequence["ValidatorTypeDef"],
         "Tags": Mapping[str, str],
+        "Type": str,
     },
     total=False,
 )
@@ -273,7 +276,7 @@ _RequiredCreateHostedConfigurationVersionRequestRequestTypeDef = TypedDict(
     {
         "ApplicationId": str,
         "ConfigurationProfileId": str,
-        "Content": Union[bytes, IO[bytes], StreamingBody],
+        "Content": Union[str, bytes, IO[Any], StreamingBody],
         "ContentType": str,
     },
 )
@@ -596,6 +599,7 @@ _OptionalListConfigurationProfilesRequestRequestTypeDef = TypedDict(
     {
         "MaxResults": int,
         "NextToken": str,
+        "Type": str,
     },
     total=False,
 )
@@ -693,15 +697,25 @@ ListTagsForResourceRequestRequestTypeDef = TypedDict(
     },
 )
 
-MonitorTypeDef = TypedDict(
-    "MonitorTypeDef",
+_RequiredMonitorTypeDef = TypedDict(
+    "_RequiredMonitorTypeDef",
     {
         "AlarmArn": str,
+    },
+)
+_OptionalMonitorTypeDef = TypedDict(
+    "_OptionalMonitorTypeDef",
+    {
         "AlarmRoleArn": str,
     },
     total=False,
 )
 
+
+class MonitorTypeDef(_RequiredMonitorTypeDef, _OptionalMonitorTypeDef):
+    pass
+
+
 ResourceTagsTypeDef = TypedDict(
     "ResourceTagsTypeDef",
     {
